package cn.estsh.i3plus.ext.mes.apiservice.controller.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesShippingOrderManagementService;
import cn.estsh.i3plus.ext.mes.apiservice.config.AuthUtilExt;
import cn.estsh.i3plus.ext.mes.pojo.constant.MesCommonConstant;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.enumutil.ResourceEnumUtil;
import cn.estsh.i3plus.pojo.mes.bean.MesShippingOrderManagement;
import cn.estsh.i3plus.pojo.mes.util.MesExtEnumUtil;
import cn.estsh.impp.framework.boot.exception.ImppBusiException;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ResultBean;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.CollectionUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.stream.Collectors;

@Api(description = "发运单管理主页面")
@RestController
@RequestMapping(MesCommonConstant.MES_YANFEN + "/mesShippingOrderManagement")

public class MesShippingOrderManagementController extends BaseMesController<MesShippingOrderManagement> {


    @Autowired
    private IMesShippingOrderManagementService shippingOrderManagementService;

    @PostMapping(value = "/shipping")
    @ApiOperation(value = "发运")
    public ResultBean<MesShippingOrderManagement> saveShipping(@RequestBody List<MesShippingOrderManagement> beanList) {
        try {

            List<String> orderNoList =
                    beanList.stream().filter(k -> k.getStatus() != MesExtEnumUtil.SHIPPING_ORDER_STATUS.CREATE.getValue() &&
                            k.getStatus() != MesExtEnumUtil.SHIPPING_ORDER_STATUS.PUBLISHED.getValue()).map(k -> k.getShippingCode()).collect(Collectors.toList());

            if (!CollectionUtils.isEmpty(orderNoList)) {
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                        .setErrorDetail("【%s】发运单状态不是【%s】或【%s】，请选择状态为【%s】或【%s】的数据", orderNoList, MesExtEnumUtil.SHIPPING_ORDER_STATUS.CREATE.getDescription(),
                                MesExtEnumUtil.SHIPPING_ORDER_STATUS.PUBLISHED.getDescription(), MesExtEnumUtil.SHIPPING_ORDER_STATUS.CREATE.getDescription(),
                                MesExtEnumUtil.SHIPPING_ORDER_STATUS.PUBLISHED.getDescription())
                        .build();
            }
            //新增初始化
            for (MesShippingOrderManagement orderManagement : beanList) {
                orderManagement.setOrganizeCode(AuthUtilExt.getOrganizeCode());
                shippingOrderManagementService.saveShipping(orderManagement);
            }

            return ResultBean.success("操作成功")
                    .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        } catch (ImppBusiException e) {
            return ResultBean.fail(e).build();
        } catch (Exception e) {
            return ResultBean.fail(e);
        }
    }

    @PostMapping(value = "/close")
    @ApiOperation(value = "关闭发运单")
    public ResultBean<MesShippingOrderManagement> saveShippingClose(@RequestBody List<MesShippingOrderManagement> beanList) {
        try {

//            List<String> orderNoList =
//                    beanList.stream().filter(k -> k.getStatus() != MesExtEnumUtil.SHIPPING_ORDER_STATUS.CREATE.getValue() &&
//                            k.getStatus() != MesExtEnumUtil.SHIPPING_ORDER_STATUS.PUBLISHED.getValue()).map(k -> k.getShippingCode()).collect(Collectors.toList());
//
//            if (!CollectionUtils.isEmpty(orderNoList)) {
//                throw ImppExceptionBuilder.newInstance()
//                        .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
//                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
//                        .setErrorDetail("【%s】发运单状态不是【%s】或【%s】，请选择状态为【%s】或【%s】的数据", orderNoList, MesExtEnumUtil.SHIPPING_ORDER_STATUS.CREATE.getDescription(),
//                                MesExtEnumUtil.SHIPPING_ORDER_STATUS.PUBLISHED.getDescription(), MesExtEnumUtil.SHIPPING_ORDER_STATUS.CREATE.getDescription(),
//                                MesExtEnumUtil.SHIPPING_ORDER_STATUS.PUBLISHED.getDescription())
//                        .build();
//            }
            //新增初始化
            for (MesShippingOrderManagement orderManagement : beanList) {
                orderManagement.setOrganizeCode(AuthUtilExt.getOrganizeCode());
                shippingOrderManagementService.saveShippingClose(orderManagement);
            }

            return ResultBean.success("操作成功")
                    .setCode(ResourceEnumUtil.MESSAGE.SUCCESS.getCode());
        } catch (ImppBusiException e) {
            return ResultBean.fail(e).build();
        } catch (Exception e) {
            return ResultBean.fail(e);
        }
    }

}
