package cn.estsh.i3plus.ext.mes.apiservice.daoimpl;

import cn.estsh.i3plus.ext.mes.apiservice.dao.IMesDefectRecordDao;
import cn.estsh.i3plus.ext.mes.pojo.model.MesDefectRecordModel;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.persistence.EntityManager;
import javax.persistence.Query;
import java.util.ArrayList;
import java.util.List;

/**
 * @Description :SAP生产计划
 * @Reference :
 * @Author : junsheng.li
 * @CreateDate 2024/5/6 15:52
 * @Modify:
 **/
@Service
@Slf4j
public class MesDefectRecordDaoImpl implements IMesDefectRecordDao {


    @Autowired
    private EntityManager entityManager;


    @Override
    public List<MesDefectRecordModel> queryMesDefectRecordGroupBy(String organizeCode, Integer count, String createDateTimeStart, String createDateTimeEnd) {

        StringBuffer hql = new StringBuffer("select mdr.part_no ,mp.part_type_code , mdr.sides ,mdr.defect_location_code ,mdr.defect_code  ");
        hql.append(" from mes_defect_record as mdr");
        hql.append(" inner join mes_part as mp where mdr.part_no = mp.part_no and mdr.organize_code = mp.organize_code  ");
        hql.append(" and mdr.is_deleted = mp.is_deleted and mdr.is_valid = mp.is_valid ");
        hql.append(" where mdr.organize_code = :organizeCode ");
        hql.append(" and mdr.is_deleted = :isDeleted ");
        hql.append(" and mdr.is_valid = :isValid ");
        hql.append(" and mdr.nc_type = 0 ");
        hql.append(" and sap.create_date_time >= :createDateTimeStart");
        hql.append(" and sap.create_date_time <= :createDateTimeEnd");

        hql.append(" group by mdr.part_no ,mp.part_type_code mdr.sides ,mdr.defect_location_code ,mdr.defect_code ");
        hql.append(" having count() > " + count);

        Query query = entityManager.createNativeQuery(hql.toString());
        query.setParameter("organizeCode", organizeCode);
        query.setParameter("isValid", CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
        query.setParameter("isDeleted", CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());
        query.setParameter("createDateTimeStart", createDateTimeStart);
        query.setParameter("createDateTimeEnd", createDateTimeEnd);

        List list = query.getResultList();

        List<MesDefectRecordModel> modelList = new ArrayList<>();

        for (Object result : list) {
            Object[] cells = (Object[]) result;
            MesDefectRecordModel model = new MesDefectRecordModel();
            String partNo = String.valueOf(cells[0]);
            String partTypeCode = String.valueOf(cells[1]);
            String sides = String.valueOf(cells[2]);
            String defectLocationCode = String.valueOf(cells[3]);
            String defectCode = String.valueOf(cells[4]);
            model.setPartNo(partNo);
            model.setPartTypeCode(partTypeCode);
            model.setFrontBack(Integer.parseInt(sides));
            model.setDefectLocation(defectLocationCode);
            model.setDefectTypeCode(defectCode);
            modelList.add(model);
        }

        return modelList;

    }
}
