package cn.estsh.i3plus.ext.mes.apiservice.daoimpl;

import cn.estsh.i3plus.ext.mes.apiservice.dao.IMesShippingOrderManagementDetailDao;
import cn.estsh.i3plus.ext.mes.pojo.model.MesShippingOrderManagementDetailModel;
import cn.estsh.i3plus.pojo.base.common.Pager;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.mes.bean.MesShippingOrderManagementDetail;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import javax.persistence.EntityManager;
import javax.persistence.Query;
import java.util.ArrayList;
import java.util.List;

/**
 * @Description :SAP生产计划
 * @Reference :
 * @Author : junsheng.li
 * @CreateDate 2024/5/6 15:52
 * @Modify:
 **/
@Service
@Slf4j
public class MesShippingOrderManagementDetailDaoImpl implements IMesShippingOrderManagementDetailDao {


    @Autowired
    private EntityManager entityManager;

    @Override
    public int queryOrderDetailGroupByPartCount(MesShippingOrderManagementDetail detail) {

        StringBuffer hql = new StringBuffer("select count(1)  ");
        hql.append(" from mes_shipping_detail as msd");
        hql.append(" where msd.organize_code = :organizeCode ");
        hql.append(" and msd.is_deleted = :isDeleted ");
        hql.append(" and msd.is_valid = :isValid ");

        hql.append(" and msd.shipping_order_no = :shippingOrderNo ");

        hql.append(" group by msd.part_no ,msd.part_name,msd.cust_part_no,msd.unit ");

        Query query = entityManager.createNativeQuery(hql.toString());
        query.setParameter("organizeCode", detail.getOrganizeCode());
        query.setParameter("isValid", CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
        query.setParameter("isDeleted", CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());
        query.setParameter("shippingCode", detail.getShippingCode());

        List list = query.getResultList();

        if (CollectionUtils.isEmpty(list)) {
            return 0;
        }

        return list.size();
    }

    @Override
    public List<MesShippingOrderManagementDetailModel> queryOrderDetailGroupByPartInfo(MesShippingOrderManagementDetail detail, Pager pager) {


        StringBuffer hql = new StringBuffer("select msd.part_no ,msd.part_name, msd.cust_part_no,sum( msd.plan_qty) as planQty , sum( msd.actual_qty) as actualQty,  msd.unit ");
        hql.append(" from mes_shipping_detail as msd");
        hql.append(" where msd.organize_code = :organizeCode ");
        hql.append(" and msd.is_deleted = :isDeleted ");
        hql.append(" and msd.is_valid = :isValid ");

        hql.append(" and msd.shipping_order_no = :shippingOrderNo ");

        hql.append(" group by msd.part_no ,msd.part_name,msd.cust_part_no,msd.unit ");

        Query query = entityManager.createNativeQuery(hql.toString());
        query.setParameter("organizeCode", detail.getOrganizeCode());
        query.setParameter("isValid", CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
        query.setParameter("isDeleted", CommonEnumUtil.TRUE_OR_FALSE.FALSE.getValue());
        query.setParameter("shippingCode", detail.getShippingCode());


        query.setFirstResult(pager.getStartRow()).setMaxResults(pager.getPageSize());

        List list = query.getResultList();
        List<MesShippingOrderManagementDetailModel> modelList = new ArrayList<>();

        for (Object result : list) {
            Object[] cells = (Object[]) result;
            MesShippingOrderManagementDetailModel model = new MesShippingOrderManagementDetailModel();
            model.setPartNo(StringUtils.isEmpty(cells[0]) ? "" : String.valueOf(cells[0]));
            model.setPartName(StringUtils.isEmpty(cells[1]) ? "" : String.valueOf(cells[1]));
            model.setCustPartNo(StringUtils.isEmpty(cells[2]) ? "" : String.valueOf(cells[2]));
            model.setActualQty(StringUtils.isEmpty(cells[3]) ? 0 : Integer.parseInt(String.valueOf(cells[3])));
            model.setActualQty(StringUtils.isEmpty(cells[4]) ? 0 : Integer.parseInt(String.valueOf(cells[4])));
            model.setUnit(StringUtils.isEmpty(cells[5]) ? "" : String.valueOf(cells[5]));
            modelList.add(model);
        }

        return modelList;
    }
}
