package cn.estsh.i3plus.ext.mes.apiservice.dbinterface;

import cn.estsh.i3plus.platform.common.tool.TimeTool;
import cn.estsh.i3plus.platform.plugin.datasource.DynamicDataSourceProxy;
import cn.estsh.i3plus.pojo.base.codemaker.SnowflakeIdMaker;
import cn.estsh.impp.framework.boot.util.LocaleUtils;
import lombok.Getter;
import lombok.Setter;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.sql.Connection;

/**
 * @Description :
 * @Reference :
 * @Author : gsz
 * @CreateDate : 2024-05-10 16:08
 * @Modify:
 **/
@Component
public class WmsSAPDbQuery {
    public static final Logger LOGGER = LoggerFactory.getLogger(WmsSAPDbQuery.class);
    public static boolean needI18N = true;
    /*@Resource(name = "wmsDataSource")
    private DynamicDataSourceProxy wmsDataSourceProxy;*/

    @Resource(name = "mesDataSource")
    private DynamicDataSourceProxy mesDataSourceProxy;

    @Autowired
    private SnowflakeIdMaker snowflakeIdMaker;


    @Getter
    @Setter
    private  MesSAPDbDataMapper mesSAPDbDataMapper;

    @Getter
    @Setter
    private Connection srcConn;

    /**
     * 根据单据类型获取单据存放的表名
     *
     * @param orderType 单据类型
     * @return 单据的表名
     */
    private String getOrderTypeTable(String orderType,String organizeCode) {
        String sqlTableName = "";

        switch (orderType.trim().toUpperCase()) {
            case "ASN":
                sqlTableName = "wms_doc_asn_details_"+organizeCode;
                break;
            case "PO":
                sqlTableName = "wms_doc_po_details";
                break;
            case "MOVE":
                sqlTableName = "wms_doc_movement_details_"+organizeCode;
                break;
            case "CS":
                sqlTableName = "wms_doc_cs_details_"+organizeCode;
                break;
            default:
                break;
        }

        if (StringUtils.isEmpty(sqlTableName)) {
            throw new RuntimeException("单据类型必须是 ASN/PO/MOVE/CS 中的一种！");
        }

        return sqlTableName;
    }

    /**
     * 将字符串转换成指定的格式（需要指定源字符串的格式）
     *
     * @param value      要转换的字符串
     * @param srcFormat  原始格式
     * @param destFormat 目标格式
     * @return
     * @throws Exception
     */
    public String strFormat(String value, String srcFormat, String destFormat) throws Exception {
        return TimeTool.parseStringFormat(value, srcFormat, destFormat);
    }
   /**
     * 翻译带参数的字符串
     *
     * @param msg  字符串
     * @param args String.format 参数
     * @return 翻译后的字符串
     */
    public static String lz(String msg, Object... args) {
        if (!needI18N) {
            return String.format(msg, args);
        }
        return String.format(LocaleUtils.getLocaleRes(msg), args);
    }
}
