package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesCustomerOriganzeService;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesCustomerOriganze;
import cn.estsh.i3plus.pojo.mes.repository.MesCustomerCarModelRepository;
import cn.estsh.i3plus.pojo.mes.repository.MesCustomerRepository;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author yinxiao
 * @date 2023-2023/6/2 10:54
 * @Description
 */
@Service
@Slf4j
public class MesCustomerOriganzeService extends BaseMesService<MesCustomerOriganze> implements IMesCustomerOriganzeService {

    @Autowired
    private MesCustomerCarModelRepository mesCustomerCarModelRDao;
    @Autowired
    private MesCustomerRepository customerRepository;

    protected void onInsertBean(MesCustomerOriganze item) {
        // 数据校验
        ValidatorBean.checkNotNull(item.getCustCode(), "客户代码不能为空");

        DdlPackBean roadPackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getCustCode(), "custCode", roadPackBean);
        DdlPreparedPack.getStringEqualPack(item.getCustOrganizeCode(), "custOrganizeCode", roadPackBean);

        boolean flg = baseRDao.isExitByHql(roadPackBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("客户工厂【%s】下客户代码【%s】已经存在，请检查数据", item.getCustOrganizeCode(),item.getCustCode())
                    .build();
        }

    }

    protected void onUpdateBean(MesCustomerOriganze item) {
        // 数据校验
        ValidatorBean.checkNotNull(item.getCustCode(), "客户代码不能为空");

        DdlPackBean roadPackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getCustCode(), "custCode", roadPackBean);
        DdlPreparedPack.getStringEqualPack(item.getCustOrganizeCode(), "custOrganizeCode", roadPackBean);

        DdlPreparedPack.getNumNOEqualPack(item.getId(), "id", roadPackBean);
        boolean flg = baseRDao.isExitByHql(roadPackBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("客户工厂【%s】下客户代码【%s】已经存在，请检查数据", item.getCustOrganizeCode(),item.getCustCode())
                    .build();
        }
    }


    protected void setPackQueryBean(MesCustomerOriganze bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringEqualPack(bean.getCustOrganizeCode(), "custOrganizeCode", packBean);
        DdlPreparedPack.getStringLikerPack(bean.getCustOrganizeName(), "custOrganizeName", packBean);
        DdlPreparedPack.getStringEqualPack(bean.getCustCode(), "custCode", packBean);

    }

    protected void onDeleteId(Long id) {
        MesCustomerOriganze mesCustomerOriganze = baseRDao.getById(id);
        //校验客户车型配置
        DdlPackBean packBean = DdlPackBean.getDdlPackBean(mesCustomerOriganze.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(mesCustomerOriganze.getCustOrganizeCode(), "customerOrganizeCode", packBean);
        if (mesCustomerCarModelRDao.isExitByHql(packBean)) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("客户工厂【%s】存在客户车型配置信息，请先删除对应的客户车型配置信息", mesCustomerOriganze.getCustOrganizeCode())
                    .build();
        }
    }

    // 校验导入数据
    @Override
    public void validateImport(List<MesCustomerOriganze> beanList) {

        for (MesCustomerOriganze bean : beanList) {

            //todo
            //查询数据库校验字段，待确定
//            DdlPackBean packBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
//            DdlPreparedPack.getStringEqualPack(bean.getCustCode(), "custCode", packBean);
//            MesCustomer customer = customerRepository.getByProperty(packBean);
//            if (StringUtils.isEmpty(customer)) {
//                throw new ImppBusiException(String.format("客户代码【%s】不存在", bean.getCustCode()));
//            }
//
//            bean.setCustName(customer.getCustName());
        }
    }
}
