package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesItemPartErrorPreventionService;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.MesItemPartErrorPrevention;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

@Service
@Slf4j
public class MesItemPartErrorPreventionService extends BaseMesService<MesItemPartErrorPrevention> implements IMesItemPartErrorPreventionService {


    protected void onInsertBean(MesItemPartErrorPrevention item) {
        // 数据校验
        ValidatorBean.checkNotNull(item.getPreventionObjectCode(), "防错对象代码不能为空");
        ValidatorBean.checkNotNull(item.getPreventionCode(), "防错代码不能为空");

        DdlPackBean errorPrePackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getBarrelBarcode(), "barrelBarcode", errorPrePackBean);
        DdlPreparedPack.getStringEqualPack(item.getPartNo(), "partNo", errorPrePackBean);
        boolean flg = baseRDao.isExitByHql(errorPrePackBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】料桶条码【%s】零件号已经存在，请检查数据", item.getBarrelBarcode(), item.getPartNo())
                    .build();
        }

    }

    protected void onUpdateBean(MesItemPartErrorPrevention item) {
        // 数据校验
        ValidatorBean.checkNotNull(item.getPreventionObjectCode(), "防错对象代码不能为空");
        ValidatorBean.checkNotNull(item.getPreventionCode(), "防错代码不能为空");
        DdlPackBean errorPrePackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getBarrelBarcode(), "barrelBarcode", errorPrePackBean);
        DdlPreparedPack.getStringEqualPack(item.getPartNo(), "partNo", errorPrePackBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), "id", errorPrePackBean);
        boolean flg = baseRDao.isExitByHql(errorPrePackBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】料桶条码【%s】零件号已经存在，请检查数据", item.getBarrelBarcode(), item.getPartNo())
                    .build();
        }
    }

    protected void setPackQueryBean(MesItemPartErrorPrevention bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringLikerPack(bean.getBarrelBarcode(), "barrelBarcode", packBean);
        DdlPreparedPack.getStringEqualPack(bean.getPartNo(), "partNo", packBean);
        DdlPreparedPack.getStringLikerPack(bean.getPartName(), "partName", packBean);
        DdlPreparedPack.getStringLikerPack(bean.getLot(), "lot", packBean);
    }

}
