package cn.estsh.i3plus.ext.mes.apiservice.serviceimpl.base;

import cn.estsh.i3plus.ext.mes.api.base.IMesConfigService;
import cn.estsh.i3plus.ext.mes.api.base.IMesPartService;
import cn.estsh.i3plus.ext.mes.api.base.IMesShippingOrderManagementService;
import cn.estsh.i3plus.platform.common.convert.ConvertBean;
import cn.estsh.i3plus.platform.common.exception.ImppExceptionEnum;
import cn.estsh.i3plus.platform.common.tool.TimeTool;
import cn.estsh.i3plus.pojo.base.bean.DdlPackBean;
import cn.estsh.i3plus.pojo.base.enumutil.CommonEnumUtil;
import cn.estsh.i3plus.pojo.base.tool.DdlPreparedPack;
import cn.estsh.i3plus.pojo.mes.bean.*;
import cn.estsh.i3plus.pojo.mes.repository.*;
import cn.estsh.i3plus.pojo.mes.util.MesExtEnumUtil;
import cn.estsh.impp.framework.boot.auth.AuthUtil;
import cn.estsh.impp.framework.boot.exception.ImppExceptionBuilder;
import cn.estsh.impp.framework.boot.util.ValidatorBean;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.StringUtils;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

@Service
@Slf4j
public class MesShippingOrderManagementService extends BaseMesService<MesShippingOrderManagement> implements IMesShippingOrderManagementService {

    @Autowired
    private MesShippingOrderManagementDetailService detailService;

    @Autowired
    private MesPartShippingGroupDetailService shippingGroupDetailService;

    @Autowired
    private MesPartShippingGroupRepository partShippingGroupRepository;

    @Autowired
    private MesCustomerDockRepository customerDockRepository;

    @Autowired
    private MesJisShippingRepository jisShippingRepository;

    @Autowired
    private MesProduceSnRepository produceSnRepository;
    @Autowired
    private IMesConfigService configService;

    @Autowired
    private MesPartRepository partRepository;

    @Autowired
    private IMesPartService partService;


    protected void setPackQueryBean(MesShippingOrderManagement bean, DdlPackBean packBean) {
        DdlPreparedPack.getStringEqualPack(bean.getShippingGroupCode(), "shippingGroupCode", packBean);
        DdlPreparedPack.getStringEqualPack(bean.getCustCode(), "custCode", packBean);
        DdlPreparedPack.getStringEqualPack(bean.getCustOrganizeCode(), "custOrganizeCode", packBean);
        DdlPreparedPack.getNumEqualPack(bean.getStatus(), "status", packBean);
        DdlPreparedPack.getInPackArray(bean.getStatusArray(), "status", packBean);
        if (!StringUtils.isEmpty(bean.getReleaseTimeStart()) || !StringUtils.isEmpty(bean.getReleaseTimeEnd())) {
            DdlPreparedPack.timeBuilder(bean.getReleaseTimeStart(), bean.getReleaseTimeEnd(), "releaseTime", packBean, false);
        }
//        DdlPreparedPack.getOrderByPack(new Object[]{CommonEnumUtil.ASC_OR_DESC.DESC.getValue()}, new String[]{"createDatetime"}, packBean);
    }

    @Override
    public MesShippingOrderManagement insert(MesShippingOrderManagement bean) {
        //插入前构造并校验数据
        onInsertBean(bean);

        DdlPackBean partShipGroupPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(bean.getShippingGroupCode(), "shippingGroupCode", partShipGroupPackBean);
        MesPartShippingGroup partShippingGroup = partShippingGroupRepository.getByProperty(partShipGroupPackBean);

        if (StringUtils.isEmpty(partShippingGroup)) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】零件发运组数据为空，请检查数据", bean.getShippingGroupCode())
                    .build();
        }

        if (StringUtils.isEmpty(partShippingGroup.getIsLoading()) || partShippingGroup.getIsLoading() == 0) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】零件发运组是否有装车不能为空，请检查数据", bean.getShippingGroupCode())
                    .build();
        }
        if (StringUtils.isEmpty(partShippingGroup.getIsFirstInstall()) || partShippingGroup.getIsFirstInstall() == 0) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】零件发运组是否先装车不能为空，请检查数据", bean.getShippingGroupCode())
                    .build();
        }
        if (StringUtils.isEmpty(partShippingGroup.getIsEnableMemory()) || partShippingGroup.getIsEnableMemory() == 0) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】零件发运组是否启用记忆不能为空，请检查数据", bean.getShippingGroupCode())
                    .build();
        }

        DdlPackBean custDockPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(bean.getCustCode(), "custCode", custDockPackBean);
        MesCustomerDock customerDock = customerDockRepository.getByProperty(custDockPackBean);

        if (StringUtils.isEmpty(customerDock)) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】客户零件号未维护客户道口，请检查数据", bean.getCustCode())
                    .build();
        }

        bean.setCustDockCode(customerDock.getCustDockCode());
        bean.setPartShippingId(partShippingGroup.getId());
        bean.setShippingType(MesExtEnumUtil.SHIPPING_ORDER_TYPE.SORT_SHIPPING.getValue());
        bean.setIsLoading(partShippingGroup.getIsLoading());
        bean.setIsFirstInstall(partShippingGroup.getIsFirstInstall());
        bean.setIsEnableMemory(partShippingGroup.getIsEnableMemory());

        //查询物料发运组明细数据
        DdlPackBean shipGroupPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(bean.getShippingGroupCode(), "shippingGroupCode", shipGroupPackBean);
        List<MesPartShippingGroupDetail> groupDetailList = shippingGroupDetailService.findAll(shipGroupPackBean);
        if (CollectionUtils.isEmpty(groupDetailList)) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】零件发运组明细数据为空，请检查数据", bean.getShippingGroupCode())
                    .build();
        }

        //发运单明细
        List<MesShippingOrderManagementDetail> detailInsertList = new ArrayList<>();

        MesShippingOrderManagement finalBean = bean;
        groupDetailList.forEach(k -> {
            MesShippingOrderManagementDetail detail = new MesShippingOrderManagementDetail();
            BeanUtils.copyProperties(k, detail, "id");
            MesPart part = partService.getPartByPartNo(k.getPartNo(), k.getOrganizeCode());
            detail.setPartName(part.getPartName());
            detail.setUnit(part.getUnit());
            detail.setCustPartNo(k.getCustPartNo());
            detail.setPlanQty(1);
            detail.setShippingId(finalBean.getId());
//            detail.setActualQty(1);
            detail.setShippingCode(finalBean.getShippingCode());
            detail.setOrganizeCode(k.getOrganizeCode());
            detail.setStatus(MesExtEnumUtil.SHIPPING_ORDER_STATUS.CREATE.getValue());

            ConvertBean.serviceModelInitialize(detail, AuthUtil.getSessionUser().getUserName());
            detailInsertList.add(detail);
        });

        detailService.insertBatch(detailInsertList);
        bean = baseRDao.insert(bean);
        return bean;
    }


    @Override
    public MesShippingOrderManagement update(MesShippingOrderManagement bean) {
        //更新前构造并校验数据
        onUpdateBean(bean);
        MesShippingOrderManagement originBean = baseRDao.getById(bean.getId());
        if (StringUtils.isEmpty(originBean)) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("请选择需要操作的资源。")
                    .build();
        }

        //判断是否修改发运组，如果不修改发运组，则不修改明细
        if (!bean.getShippingGroupCode().equals(originBean.getShippingGroupCode())) {

            DdlPackBean partShipGroupPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
            DdlPreparedPack.getStringEqualPack(bean.getShippingGroupCode(), "shippingGroupCode", partShipGroupPackBean);
            MesPartShippingGroup partShippingGroup = partShippingGroupRepository.getByProperty(partShipGroupPackBean);

            if (StringUtils.isEmpty(partShippingGroup)) {
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                        .setErrorDetail("【%s】零件发运组数据为空，请检查数据", bean.getShippingGroupCode())
                        .build();
            }

            if (StringUtils.isEmpty(partShippingGroup.getIsLoading()) || partShippingGroup.getIsLoading() == 0) {
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                        .setErrorDetail("【%s】零件发运组是否有装车不能为空，请检查数据", bean.getShippingGroupCode())
                        .build();
            }
            if (StringUtils.isEmpty(partShippingGroup.getIsFirstInstall()) || partShippingGroup.getIsFirstInstall() == 0) {
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                        .setErrorDetail("【%s】零件发运组是否先装车不能为空，请检查数据", bean.getShippingGroupCode())
                        .build();
            }
            if (StringUtils.isEmpty(partShippingGroup.getIsEnableMemory()) || partShippingGroup.getIsEnableMemory() == 0) {
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                        .setErrorDetail("【%s】零件发运组是否启用记忆不能为空，请检查数据", bean.getShippingGroupCode())
                        .build();
            }

            DdlPackBean custDockPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
            DdlPreparedPack.getStringEqualPack(bean.getCustCode(), "custCode", custDockPackBean);
            MesCustomerDock customerDock = customerDockRepository.getByProperty(custDockPackBean);

            if (StringUtils.isEmpty(customerDock)) {
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                        .setErrorDetail("【%s】客户零件号未维护客户道口，请检查数据", bean.getCustCode())
                        .build();
            }

            bean.setCustDockCode(customerDock.getCustDockCode());
            bean.setPartShippingId(partShippingGroup.getId());
            bean.setShippingType(MesExtEnumUtil.SHIPPING_ORDER_TYPE.SORT_SHIPPING.getValue());
            bean.setIsLoading(partShippingGroup.getIsLoading());
            bean.setIsFirstInstall(partShippingGroup.getIsFirstInstall());
            bean.setIsEnableMemory(partShippingGroup.getIsEnableMemory());


            DdlPackBean detailPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
            DdlPreparedPack.getStringEqualPack(bean.getShippingCode(), "shippingCode", detailPackBean);
            List<MesShippingOrderManagementDetail> detailDeleteList = detailService.findAll(detailPackBean);
            detailDeleteList.forEach(k -> {
                k.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
                ConvertBean.serviceModelUpdate(k, AuthUtil.getSessionUser().getUserName());
            });
            //查询物料发运组数据
            DdlPackBean shipGroupPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
            DdlPreparedPack.getStringEqualPack(bean.getShippingGroupCode(), "shippingGroupCode", shipGroupPackBean);
            List<MesPartShippingGroupDetail> shippingGroupDetailList = shippingGroupDetailService.findAll(shipGroupPackBean);
            if (CollectionUtils.isEmpty(shippingGroupDetailList)) {
                throw ImppExceptionBuilder.newInstance()
                        .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                        .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                        .setErrorDetail("【%s】发运组明细数据为空，请检查数据", bean.getShippingGroupCode())
                        .build();
            }
            //发运单明细
            List<MesShippingOrderManagementDetail> detailInsertList = new ArrayList<>();
            shippingGroupDetailList.forEach(k -> {
                MesShippingOrderManagementDetail detail = new MesShippingOrderManagementDetail();
                BeanUtils.copyProperties(k, detail, "id");
                MesPart part = partService.getPartByPartNo(k.getPartNo(), k.getOrganizeCode());
                detail.setPartName(part.getPartName());
                detail.setUnit(part.getUnit());
                detail.setCustPartNo(k.getCustPartNo());
                detail.setPlanQty(1);
                detail.setShippingId(originBean.getId());
                detail.setShippingCode(originBean.getShippingCode());
                detail.setOrganizeCode(k.getOrganizeCode());
                detail.setStatus(MesExtEnumUtil.SHIPPING_ORDER_STATUS.CREATE.getValue());

                ConvertBean.serviceModelInitialize(detail, AuthUtil.getSessionUser().getUserName());
                detailInsertList.add(detail);
            });
            //软删原明细数据
            detailService.updates(detailDeleteList);
            //新增新明细数据
            detailService.insertBatch(detailInsertList);
        }

        ConvertBean.serviceModelUpdate(bean, AuthUtil.getSessionUser().getUserName());
        baseRDao.update(bean);
        return originBean;
    }


    @Override
    public void deleteWeaklyByIds(Long[] ids, String userName) {

        for (Long id : ids) {
            MesShippingOrderManagement bean = baseRDao.getById(id);
            if (StringUtils.isEmpty(bean)) continue;
            DdlPackBean detailPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
            DdlPreparedPack.getStringEqualPack(bean.getShippingCode(), "shippingCode", detailPackBean);
            List<MesShippingOrderManagementDetail> detailDeleteList = detailService.findAll(detailPackBean);
            detailDeleteList.forEach(k -> {
                k.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
                ConvertBean.serviceModelUpdate(k, AuthUtil.getSessionUser().getUserName());
            });
            bean.setIsDeleted(CommonEnumUtil.TRUE_OR_FALSE.TRUE.getValue());
            ConvertBean.serviceModelUpdate(bean, AuthUtil.getSessionUser().getUserName());
            baseRDao.update(bean);
            detailService.updates(detailDeleteList);
        }
    }


    protected void onInsertBean(MesShippingOrderManagement item) {

        // 数据校验
        ValidatorBean.checkNotNull(item.getShippingCode(), "发运单不能为空");
        ValidatorBean.checkNotNull(item.getSeq(), "顺序号不能为空");
        ValidatorBean.checkNotNull(item.getCustCode(), "客户代码不能为空");
        ValidatorBean.checkNotNull(item.getCustCode(), "客户工厂代码不能为空");
        ValidatorBean.checkNotNull(item.getShippingGroupCode(), "发运组代码不能为空");
        ValidatorBean.checkNotNull(item.getStatus(), "状态不能为空");

        DdlPackBean shipGroupPackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getShippingCode(), "shippingCode", shipGroupPackBean);
        boolean flg = baseRDao.isExitByHql(shipGroupPackBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】发运单已经存在，请检查数据", item.getShippingCode())
                    .build();
        }

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getSeq(), "seq", packBean);
        boolean flg1 = baseRDao.isExitByHql(packBean);
        if (flg1) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】顺序号已经存在，请检查数据", item.getSeq())
                    .build();
        }


    }

    protected void onUpdateBean(MesShippingOrderManagement item) {

        // 数据校验
        ValidatorBean.checkNotNull(item.getShippingCode(), "发运单不能为空");
        ValidatorBean.checkNotNull(item.getSeq(), "顺序号不能为空");
        ValidatorBean.checkNotNull(item.getCustCode(), "客户代码不能为空");
        ValidatorBean.checkNotNull(item.getCustOrganizeCode(), "客户工厂代码不能为空");
        ValidatorBean.checkNotNull(item.getShippingGroupCode(), "发运组代码不能为空");
        ValidatorBean.checkNotNull(item.getStatus(), "状态不能为空");

        DdlPackBean shipGroupPackBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getShippingCode(), "shippingCode", shipGroupPackBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), "id", shipGroupPackBean);
        boolean flg = baseRDao.isExitByHql(shipGroupPackBean);
        if (flg) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】发运单已经存在，请检查数据", item.getShippingCode())
                    .build();
        }

        DdlPackBean packBean = DdlPackBean.getDdlPackBean(item.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(item.getSeq(), "seq", packBean);
        DdlPreparedPack.getNumNOEqualPack(item.getId(), "id", packBean);
        boolean flg1 = baseRDao.isExitByHql(packBean);
        if (flg1) {
            throw ImppExceptionBuilder.newInstance()
                    .setSystemID(CommonEnumUtil.SOFT_TYPE.MES.getCode())
                    .setErrorCode(ImppExceptionEnum.VARIFY_EXCEPTION.getCode())
                    .setErrorDetail("【%s】顺序号已经存在，请检查数据", item.getSeq())
                    .build();
        }
    }


    @Override
    public void saveShipping(MesShippingOrderManagement bean) {

        MesShippingOrderManagement originBean = baseRDao.getById(bean.getId());

        DdlPackBean detailPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(originBean.getShippingCode(), "shippingCode", detailPackBean);
        List<MesShippingOrderManagementDetail> detailDeleteList = detailService.findAll(detailPackBean);

        Map<String, List<MesShippingOrderManagementDetail>> detailMap = detailDeleteList.stream().collect(Collectors.groupingBy(k -> k.getPartNo()));

        List<MesJisShipping> jisShippingList = new ArrayList<>();
        detailMap.forEach((k, v) -> {

            DdlPackBean packBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
            DdlPreparedPack.getStringEqualPack(v.get(0).getPartNo(), "partNo", packBean);
            MesPart part = partRepository.getByProperty(packBean);

            MesJisShipping jisShipping = new MesJisShipping();
            BeanUtils.copyProperties(originBean, jisShipping, "id");
            BeanUtils.copyProperties(v.get(0), jisShipping, "id");
            jisShipping.setFactoryCode(originBean.getOrganizeCode());
            jisShipping.setCusCode(originBean.getCustCode());
            jisShipping.setShippingTime(TimeTool.getNowTime(true));
            jisShipping.setDock(originBean.getSendDockCode());
            jisShipping.setErpWarerhouse(configService.getCfgValue(bean.getOrganizeCode(), "ERP_WARERHOUSE"));
            jisShipping.setErpWarehous(configService.getCfgValue(bean.getOrganizeCode(), "ERP_WAREHOUS"));
            jisShipping.setCusDock(originBean.getCustDockCode());
            jisShipping.setCustOrderNo(v.get(0).getCustOrderNo());
            jisShipping.setSerialNumber(v.get(0).getBarcode());
            jisShipping.setQuantityPerCar(v.size());
            jisShipping.setShippingOrderCode(originBean.getShippingCode());
            jisShipping.setVin(v.get(0).getVin());
            jisShipping.setCarNo(v.get(0).getVin());
            if (!StringUtils.isEmpty(part)) {
                jisShipping.setUnit(part.getUnit());
            }
            jisShipping.setOffTime(TimeTool.getNowTime(true));
            ConvertBean.serviceModelInitialize(jisShipping, AuthUtil.getSessionUser().getUserName());
            jisShippingList.add(jisShipping);
        });

        //修改当前发运单状态
        originBean.setStatus(MesExtEnumUtil.SHIPPING_ORDER_STATUS.SHIPPED.getValue());
        ConvertBean.serviceModelUpdate(originBean, AuthUtil.getSessionUser().getUserName());

        //修改当前发运单明细状态
        detailDeleteList.forEach(k -> {
            k.setActualQty(1);
            k.setStatus(MesExtEnumUtil.SHIPPING_ORDER_STATUS.SHIPPED.getValue());
            ConvertBean.serviceModelUpdate(k, AuthUtil.getSessionUser().getUserName());
        });

        ConvertBean.serviceModelUpdate(bean, AuthUtil.getSessionUser().getUserName());
        baseRDao.save(originBean);
        detailService.updates(detailDeleteList);

        jisShippingRepository.saveAll(jisShippingList);

    }

    @Override
    public void saveShippingClose(MesShippingOrderManagement bean) {

        MesShippingOrderManagement originBean = baseRDao.getById(bean.getId());

        DdlPackBean detailPackBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
        DdlPreparedPack.getStringEqualPack(originBean.getShippingCode(), "shippingCode", detailPackBean);
        List<MesShippingOrderManagementDetail> detailDeleteList = detailService.findAll(detailPackBean);

        originBean.setStatus(MesExtEnumUtil.SHIPPING_ORDER_STATUS.CLOSE.getValue());
        ConvertBean.serviceModelUpdate(originBean, AuthUtil.getSessionUser().getUserName());
        //修改当前发运单明细状态
        detailDeleteList.forEach(k -> {
            k.setActualQty(0);
            k.setStatus(MesExtEnumUtil.SHIPPING_ORDER_STATUS.CLOSE.getValue());
            ConvertBean.serviceModelUpdate(k, AuthUtil.getSessionUser().getUserName());

            //若扫描过的条码 则恢复条码
            if (!StringUtils.isEmpty(k.getBarcode())) {

                DdlPackBean packBean = DdlPackBean.getDdlPackBean(bean.getOrganizeCode());
                DdlPreparedPack.getStringEqualPack(k.getBarcode(), "productSn", packBean);
                DdlPreparedPack.getOrderByPack(new Object[]{CommonEnumUtil.ASC_OR_DESC.DESC.getValue()}, new String[]{"createDatetime"}, packBean);
                MesProduceSn produceSn = produceSnRepository.getByProperty(packBean);

                produceSn.setSnStatus(MesExtEnumUtil.PRODUCE_SN_STATUS.OFFLINE.getValue());
                ConvertBean.serviceModelUpdate(k, AuthUtil.getSessionUser().getUserName());
                produceSnRepository.save(produceSn);

            }

        });

        baseRDao.save(originBean);
        detailService.updates(detailDeleteList);

    }
}
